# Filename:     tb_herk110.do
# Filetype:     Modelsim Script File
# Date:         12 may 2011
# Update:       12 may 2015
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Demo
# Error:        -
# Version:      1.2
# Copyright:    (c)2015, De Haagse Hogeschool
#

# Transcript window
transcript on

# Recreate the RTL work directory
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
# (or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile the VHDL description and testbench,
# please note that the design and its testbench are located
# in the project root, but the simulator start in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -2008 -work work ${prefix}herk110.vhd
vcom -2008 -work work ${prefix}tb_herk110.vhd

# Start simulation with 1 ns time step
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" tb_herk110

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
add list *
add list dut/current_state
add list dut/next_state

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "Inputs"
add wave sim_areset
add wave sim_clk
add wave sim_x
add wave -divider "Internals"
add wave dut/current_state
add wave dut/next_state
add wave -divider "Outputs"
add wave sim_z

# Open Structure, Signals (waveform) and List window
view structure
view list
view wave

# Run simulation for 260 ns
run 260 ns

# Fill up the waveform in the window
wave zoom full